/**
 * Application
 */
import React, { useRef, useState } from 'react';

import { BryntumSchedulerPro, BryntumDemoHeader, BryntumThemeCombo, BryntumProjectModel } from '@bryntum/schedulerpro-react';

import { schedulerProConfig } from './AppConfig';
import { projectData } from './AppData';

import './App.scss';

import { StateProvider } from "@bryntum/schedulerpro";

const stateProvider = StateProvider.setup("local");

function App() {
    const schedulerpro = useRef();
    const project = useRef();

    const [events] = useState(projectData.events);
    const [resources] = useState(projectData.resources);
    const [assignments] = useState(projectData.assignments);
    const [dependencies] = useState(projectData.dependencies);

    return (
        <>
            {/* BryntumDemoHeader component is used for Bryntum example styling only and can be removed */}
            <BryntumDemoHeader
                children={<BryntumThemeCombo />}
            />
            <BryntumProjectModel
                ref={project}
                events={events}
                resources={resources}
                assignments={assignments}
                dependencies={dependencies}
            />
            <BryntumSchedulerPro
                ref={schedulerpro}
                project={project}
                stateProvider={stateProvider}
                {...schedulerProConfig}
            />
        </>
    );
}

export default App;
